OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "請求失敗，網路連線故障",
    "Request unauthorized. Are you logged in?" : "請求未授權，您已經登入了嗎？",
    "Request forbidden. Are you an admin?" : "請求被拒，您是管理員嗎？",
    "Can not add feed: Exists already" : "無法新增饋流：已經存在",
    "Can not add folder: Exists already" : "無法新增資料夾：已經存在",
    "Explore Service URL" : "探索服務網址",
    "Saved" : "已儲存",
    "Download" : "下載",
    "Close" : " 關閉",
    "No articles available" : "沒有文章",
    "No unread articles available" : "沒有未讀文章",
    "Open website" : "開啟網站",
    "Star article" : "加上星號",
    "Unstar article" : "移除星號",
    "Keep article unread" : "維持未讀狀態",
    "Remove keep article unread" : "停止維持未讀狀態",
    "by" : "由",
    "from" : "從",
    "Play audio" : "播放音訊",
    "Download audio" : "下載音訊",
    "Download video" : "下載影片",
    "Keyboard shortcut" : "快速鍵",
    "Description" : "描述",
    "right" : "右邊",
    "Jump to next article" : "跳到下篇文章",
    "left" : "左邊",
    "Jump to previous article" : "跳到上篇文章",
    "Toggle star article" : "切換文章星號",
    "Star article and jump to next one" : "加上星號並跳到下一篇",
    "Toggle keep current article unread" : "切換維持目前文章未讀",
    "Open article in new tab" : "在新分頁開啟文章",
    "Toggle expand article in compact view" : "切換是否在精簡模式中展開文章",
    "Refresh" : "重新整理",
    "Load next feed" : "載入下個饋流",
    "Load previous feed" : "載入上個饋流",
    "Load next folder" : "載入下個資料夾",
    "Load previous folder" : "載入上個資料夾",
    "Scroll to active navigation entry" : "捲動至使用中的導覽項",
    "Focus search field" : "進入搜尋框",
    "Mark current article's feed/folder read" : "標示目前文章所在的饋流或資料夾為已讀",
    "Subscribe" : "訂閱",
    "Web address" : "網頁位址",
    "Feed exists already!" : "訂閱已經存在！",
    "Folder" : "資料夾",
    "No folder" : "無資料夾",
    "New folder" : "新資料夾",
    "Folder name" : "資料夾名稱",
    "Go back" : "返回",
    "Folder exists already!" : "資料夾已經存在！",
    "Credentials" : "帳密",
    "Username" : "使用者名稱",
    "Password" : "密碼",
    "New Folder" : "新資料夾",
    "Create" : "建立",
    "Explore" : "探索",
    "Deleted feed" : "刪除饋流",
    "Undo delete feed" : "取消刪除饋流",
    "Rename" : "重新命名",
    "Menu" : "選單",
    "Newest first" : "最新先",
    "Oldest first" : "最舊先",
    "Delete" : "刪除",
    "Dismiss" : "取消",
    "Collapse" : "收合",
    "Deleted folder" : "已刪除的資料夾",
    "Undo delete folder" : "取消刪除資料夾",
    "Starred" : "星號",
    "Unread articles" : "未讀文章",
    "All articles" : "所有文章",
    "Settings" : "設定",
    "Show all articles" : "顯示全部文章",
    "Reverse ordering (oldest on top)" : "反向排序 (最舊的文章排在最上面)",
    "Subscriptions (OPML)" : "訂閱 (OPML)",
    "Import" : "匯入",
    "Export" : "匯出",
    "Unread/Starred Articles" : "未讀/已加星號 文章",
    "Error when importing: file does not contain valid JSON" : "匯入錯誤: 檔案包含非法的JSON數據",
    "Help" : "說明",
    "Keyboard shortcuts" : "快速鍵",
    "Documentation" : "說明文件",
    "Report a bug" : "回報問題"
},
"nplurals=1; plural=0;");
